@@ -1,7 +1,7 @@
 """
 Type annotations for imagebuilder service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/type_defs/)
 
 Usage::
 
@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ComponentTypeType,
     EbsVolumeTypeType,
